<?php
    class FFVE_ADMIN_SETTINGS {
        private $options;
        public function __construct() {
            add_action('admin_menu', array($this, 'add_plugin_page'));
            add_action('admin_init', array($this, 'page_init'));
			if (_FFVE_SERVICES_DEBUG_)
			error_log('start ' . plugin_basename(__FILE__)); // Verify the plugin basename
			add_filter('plugin_action_links_ffveservices/ffveservices.php', array($this, 'add_action_links'));
		}
        public function add_plugin_page() {
            // Add a new submenu under Settings:
            add_options_page(
			'FFVE Services', // page_title
			'FFVE Services', // menu_title
			'manage_options', // capability
			'ffve-settings', // menu_slug
			array($this, 'create_admin_page') // function
            );
			// Ajout du sous-menu "Vérifier la configuration"
			add_submenu_page(
			'ffve-services',                // Parent slug
			'Vérifier la configuration',    // Titre de la page
			'Vérifier la configuration',    // Titre du sous-menu
			'manage_options',               // Capacité requise pour accéder à ce sous-menu
			'ffve-check-settings',          // Slug du sous-menu
			array($this, 'check_settings')  // Fonction de rappel pour afficher le contenu de la page
			);
		}
		public function add_action_links($links) {
			$settings_link = '<a href="options-general.php?page=ffve-settings">' . __('Réglages', 'ffveservices') . '</a>';
			array_unshift($links, $settings_link);
			return $links;
		}
		public function check_settings() {
			$this->create_admin_page(true);
		}
        public function create_admin_page($checkConfig=false) {
            wp_enqueue_style('ffve-admin-style');
			// Set class property
            $this->options = get_option('ffve_options');
			if ($checkConfig){
				$ffve_settings = new FFVE_SETTINGS();
				$ffve_api = new FFVE_API($ffve_settings->getServer(), $ffve_settings->getUser(), $ffve_settings->getPassword() );
				$result=$ffve_api->checkConfig();
				if (is_array($result) && $result['success'] === true) {
					echo '<div class="notice notice-success is-dismissible">';
					echo '<p>Configuration validée !</p>';
					echo '</div>';
					} else {
					echo '<div class="notice notice-error is-dismissible">';
					echo '<p>Une erreur est survenue ! ' . $result['message'] . '</p>';
					echo '</div>';
				}
				return;
			}
		?>
		<div class="wrap">
			<h1>FFVE Settings - Version <?php echo _FFVE_SERVICES_VERSION_; ?></h1>
			<form method="post" action="options.php">
                <?php
                    // This prints out all hidden setting fields
                    settings_fields('ffve_option_group');
                    do_settings_sections('ffve-settings-admin');
					// echo '<a href="admin.php?page=ffve-check-settings" class="button button-primary"><i class="dashicons dashicons-admin-tools"></i> Vérifier la configuration</a>';
					submit_button();
				?>
			</form>
		</div>
		<?php
		}
        public function page_init() {
			
            register_setting(
			'ffve_option_group', // option_group
			'ffve_options', // option_name
			array($this, 'sanitize') // sanitize_callback
            );
            add_settings_section(
			'setting_section_id', // id
			'FFVE Services Settings', // title
			array($this, 'print_section_info'), // callback
			'ffve-settings-admin' // page
            );
            add_settings_field(
			'login_ffve', // id
			'Identifiant : ', // title
			array($this, 'login_ffve_callback'), // callback
			'ffve-settings-admin', // page
			'setting_section_id' // section
            );
            add_settings_field(
			'password_ffve',
			'Mot de passe : ',
			array($this, 'password_ffve_callback'),
			'ffve-settings-admin',
			'setting_section_id'
            );
            add_settings_field(
			'coupon_code',
			'Code de réduction : ',
			array($this, 'coupon_code_callback'),
			'ffve-settings-admin',
			'setting_section_id'
            );
            add_settings_field(
			'mode_prod',
			'Mode production : <br><span style="font-weight:500">Active la gestion du code membre et le reporting sur le front office</span>',
			array($this, 'mode_prod_callback'),
			'ffve-settings-admin',
			'setting_section_id'
            );
            add_settings_field(
			'server',
			'Serveur API FFVE Services : ',
			array($this, 'server_callback'),
			'ffve-settings-admin',
			'setting_section_id'
            );
		}
        public function sanitize($input) {
            $new_input = array();
            if(isset($input['login_ffve']))
			$new_input['login_ffve'] = sanitize_text_field($input['login_ffve']);
			// Check if the password field is set and not empty
			if(isset($input['password_ffve']) && !empty($input['password_ffve'])) {
				// If the password is set and not empty, hash and store it
				$new_input['password_ffve'] = hash('sha256', sanitize_text_field($input['password_ffve']));
				} else {
				// If the password is empty, retain the old password value
				$options = get_option('ffve_options');
				if(isset($options['password_ffve'])) {
					$new_input['password_ffve'] = $options['password_ffve'];
				}
			}
            if(isset($input['coupon_code']))
			$new_input['coupon_code'] = sanitize_text_field($input['coupon_code']);
            if(isset($input['mode_prod']))
			$new_input['mode_prod'] = absint($input['mode_prod']);
            if(isset($input['server']))
			$new_input['server'] = sanitize_text_field($input['server']);
            return $new_input;
		}
        public function print_section_info() {
            print 'Indiquez votre identifiant FFVE Services et votre mot de passe. Choisissez le code coupon qui sera assigné aux membres de FFVE Services';
		}
        public function login_ffve_callback() {
            printf(
			'<input type="text" id="login_ffve" name="ffve_options[login_ffve]" value="%s" />',
			isset($this->options['login_ffve']) ? esc_attr($this->options['login_ffve']) : ''
            );
		}
        public function password_ffve_callback() {
            printf(
			'<input type="password" placeholder="%s" id="password_ffve" name="ffve_options[password_ffve]" value="%s" />',
			isset($this->options['no_password_ffve']) ? 'Tapez le mot de passe' : '******************', isset($this->options['no_password_ffve']) ? esc_attr($this->options['password_ffve']) : ''
            );
		}
        public function coupon_code_callback() {
            // Fetch active coupon codes
            $activeCouponCodes = $this->getActiveCouponCodes();
            printf(
		'<select id="coupon_code" name="ffve_options[coupon_code]">%s</select>',
		$this->generate_options($activeCouponCodes, isset($this->options['coupon_code']) ? $this->options['coupon_code'] : '')
		);
		}
        public function mode_prod_callback() {
		$checked = isset($this->options['mode_prod']) && $this->options['mode_prod'] === 1 ? 'checked' : '';
		printf(
		'<input type="checkbox" id="mode_prod" name="ffve_options[mode_prod]" value="1" %s />',
		$checked
		);
		}
        public function server_callback() {
		$server = isset($this->options['server']) ? $this->options['server'] : '';
		printf(
		'<input type="radio" id="server_test" name="ffve_options[server]" value="dev.ffveservices.com" %s /> Version mode test<br>',
		checked($server, 'dev.ffveservices.com', false)
		);
		printf(
		'<input type="radio" id="server_prod" name="ffve_options[server]" value="api.ffveservices.com" %s /> Version mode production*',
		checked($server, 'api.ffveservices.com', false)
		);
		echo "<br><br><em>* Vous pouvez utiliser le serveur de production uniquement après avoir eu la validation de FFVE Services</em>";
		}
        private function getActiveCouponCodes() {
		global $wpdb;
		$coupons = $wpdb->get_results("SELECT post_title, ID FROM {$wpdb->prefix}posts WHERE post_type = 'shop_coupon' AND post_status = 'publish'");
		$coupon_options = array();
		foreach ($coupons as $coupon) {
		$coupon_options[] = array('id' => $coupon->ID, 'name' => $coupon->post_title);
		}
		return $coupon_options;
		}
        private function generate_options($options, $selected) {
		$html = '';
		foreach ($options as $option) {
		$html .= sprintf(
		'<option value="%s" %s>%s</option>',
		$option['id'],
		selected($selected, $option['id'], false),
		$option['name']
		);
		}
		return $html;
		}
		}		