<?php 
	/*
	pending (En attente) : La commande a été créée, mais le paiement n'a pas encore été reçu.
	processing (En cours de traitement) : Le paiement a été reçu, et la commande est en cours de préparation pour l'expédition. Ce statut est attribué automatiquement pour les commandes payées en ligne (Stripe, PayPal, etc.).
	on-hold (En attente) : Le paiement est en attente de confirmation (par exemple, pour les paiements par chèque ou virement bancaire).
	completed (Terminée) : La commande a été expédiée et est considérée comme terminée.
	cancelled (Annulée) : La commande a été annulée par le client ou l'administrateur.
	refunded (Remboursée) : La commande a été remboursée.
	failed (Échouée) : Le paiement de la commande a échoué ou a été rejeté.
	*/
class FFVE_ORDER {
    public function __construct() {
        add_action('init', array($this, '_init'));
    }
    public function _init() {
        // Ajouter des actions pour surveiller les changements de statut des commandes
        if (_FFVE_MOD_PROD_) {
            add_action('woocommerce_order_status_changed', array($this, 'order_intercept'), 10, 4);
        }
        // Ajouter des colonnes et afficher les métadonnées dans l'admin
        if (is_admin()) {
            // Pour les commandes basées sur les CPT
            add_filter('manage_edit-shop_order_columns', array($this, 'add_custom_columns'), 20);
            add_action('manage_shop_order_posts_custom_column', array($this, 'render_custom_columns'), 25, 2);
            // Pour les commandes basées sur HPOS
            add_filter('manage_woocommerce_page_wc-orders_columns', array($this, 'add_custom_columns'), 20);
            add_action('manage_woocommerce_page_wc-orders_custom_column', array($this, 'render_custom_columns'), 25, 2);
            add_action('woocommerce_admin_order_data_after_order_details', array($this, 'display_order_meta'), 10, 1);
        }
    }
    public function add_custom_columns($columns) {
        // Ajouter nos colonnes avant "Total" ou toute autre colonne spécifiée
        $columns = array_slice($columns, 0, 4, true)
            + array('source_ffve_services' => __('Source FFVE', 'text_domain'))
            + array('membre_ffve_services' => __('Membre FFVE', 'text_domain'))
            + array_slice($columns, 4, NULL, true);
        return $columns;
    }
    public function render_custom_columns($column, $order_or_order_id) {
        // Compatibilité avec les commandes basées sur CPT et HPOS
        $order = $order_or_order_id instanceof WC_Order ? $order_or_order_id : wc_get_order($order_or_order_id);
        if ($column === 'source_ffve_services') {
            $value = $order->get_meta('_source_ffve_services', true);
            echo $value ? __('Oui', 'text_domain') : __('Non', 'text_domain');
        }
        if ($column === 'membre_ffve_services') {
            $value = $order->get_meta('_membre_ffve_services', true);
            echo $value ? __('Oui', 'text_domain') : __('Non', 'text_domain');
        }
    }
  public function display_order_meta($order) {
    // Récupérer les métadonnées via l'objet WC_Order
    $source_ffve_services = $order->get_meta('_source_ffve_services', true);
    $membre_ffve_services = $order->get_meta('_membre_ffve_services', true);
    // Afficher les métadonnées dans les détails de la commande
    echo '<br clear="all"><p><strong>' . __('Source FFVE Services', 'text_domain') . ' : </strong> ' . ($source_ffve_services ? __('Oui', 'text_domain') : __('Non', 'text_domain')) . '</p>';
    echo '<p><strong>' . __('Membre FFVE Services', 'text_domain') . ' : </strong> ' . ($membre_ffve_services ? __('Oui', 'text_domain') : __('Non', 'text_domain')) . '</p>';
}
    public function order_intercept($order_id) {
        $code_membre = NULL;
        $isFFVE = false;
        $order = wc_get_order($order_id);
        if (!$order) {
            return;
        }
        // Gestion des cookies et de la session
        if (isset($_COOKIE['sourceffve']) && $_COOKIE['sourceffve'] === 'ffveservices') {
            $isFFVE = true;
            $order->update_meta_data('_source_ffve_services', true);
        }
        
		$isActiveMember = false;

		try {
			// Vérifiez la session WooCommerce si elle est disponible
			if (function_exists('WC') && WC()->session && WC()->session->has_session()) {
				$coupon_code = WC()->session->get('ffve_custom_coupon_code');
				$isActiveMember = !empty($coupon_code); // True si le code existe
			}
		} catch (Exception $e) {
			error_log("Erreur lors de la vérification de la session WooCommerce : " . print_r($e,true));
		}

		
		if (isset($_COOKIE['tokenffve'])) {
            $isFFVE = true;
            $code_membre = FFVE_TOOLS::dechiffrement($_COOKIE['tokenffve']);
            $order->update_meta_data('_membre_ffve_services', true);
        } elseif ($isActiveMember) {
		   $isFFVE = true;
            $code_membre = WC()->session->get('ffve_custom_coupon_code');
            $order->update_meta_data('_membre_ffve_services', true);
        }
		
		
		
		
        if (is_admin()) {
            // Logique spécifique à l'admin
			$source_ffve_services = $order->get_meta('_source_ffve_services', true);
			$membre_ffve_services = $order->get_meta('_membre_ffve_services', true);
			if ( $source_ffve_services || $membre_ffve_services ){
			$isFFVE=true;
			}
        }
        if ($isFFVE) {
            if (!$code_membre) {
                $code_membre = "INCONNU";
            }
			// $order->update_meta_data('_order_origin', 'FFVE Services');
			 $total_ht_with_discount = 0;
			foreach ($order->get_items() as $item) {
					$item_total_ht = $item->get_total(); // Montant total HT après remise pour cet article
					$total_ht_with_discount += $item_total_ht;
			}
            $payload = [
                'submittedCouponCode' => $code_membre,
                'totalOrderAmount' => $order->get_total(),  // Total TTC incluant la remise
                'totalQuantity' => $order->get_item_count(),
                'totalHT' => $total_ht_with_discount, // Total HT incluant la remise
                'shippingAmount' => $order->get_shipping_total(),
                'orderStatus' => $order->get_status(),
            ];
            // Envoyer les informations à l'API FFVE si non envoyé précédemment
            $ffve_services_sent = $order->get_meta('_ffve_services_sent');
           // if (!$ffve_services_sent) {
                $ffve_settings = new FFVE_SETTINGS();
                $ffve_api = new FFVE_API($ffve_settings->getServer(), $ffve_settings->getUser(), $ffve_settings->getPassword());
                $transaction = $ffve_api->setTransaction($order_id, $payload);
                $order->update_meta_data('_ffve_services_sent', $transaction['success']);
            //}
            $order->save();
            // Mettre à jour l'utilisateur s'il existe
            $user_id = $order->get_user_id();
            if ($user_id) {
                $user_meta = get_user_meta($user_id, '_membre_ffveservices', true);
                if (!$user_meta) {
                    update_user_meta($user_id, '_membre_ffveservices', true);
                }
            }
        }
    }
}