<?php
	class FFVE_PRODUCT {
		public function __construct($addActions=true) {
			if ($addActions){
				add_action('woocommerce_product_options_general_product_data', function() {
					$this->add_export_checkbox('general');
				});
				add_action('woocommerce_product_options_inventory_product_data', function() {
					$this->add_export_checkbox('inventory');
				});
				add_action('woocommerce_process_product_meta', array($this, 'save_export_checkbox'));
				add_action('wp_ajax_ffve_export_product', array($this, 'export_ffve_products'));
				add_action('wp_ajax_ffve_upload_product', array($this, 'upload_ffve_products'));
			}
		}
		// Ajouter la case à cocher
		public function add_export_checkbox($hook) {
			global $product_object;
			// Vérifier la configuration globale de WooCommerce pour les taxes
			$calc_taxes = get_option('woocommerce_calc_taxes') === 'yes';
			// Condition pour l'onglet "Général"
			if ($hook === 'general') {
				// Afficher si ce n'est pas un produit variable ou si les taxes sont activées
				if ($product_object->get_type() !== 'variable' || $calc_taxes) {
					$this->render_export_checkbox();
				}
			}
			// Condition pour l'onglet "Inventaire"
			if ($hook === 'inventory') {
				// Afficher uniquement si c'est un produit variable et que les taxes sont désactivées
				if ($product_object->get_type() === 'variable' && !$calc_taxes) {
					$this->render_export_checkbox();
				}
			}
		}
		private function render_export_checkbox() {
			// Fonction pour afficher la case à cocher
			woocommerce_wp_checkbox(
			array(
            'id'          => '_export_to_ffve_services',
            'label'       => __('FFVE Services', 'ffveservices'),
            'description' => __('Cochez cette case si vous souhaitez exporter ce produit sur FFVE Services.', 'ffveservices')
			)
			);
		}
		// Sauvegarder la valeur de la case à cocher
		public function save_export_checkbox($post_id) {
			$export_to_ffve_services = isset($_POST['_export_to_ffve_services']) ? 'yes' : 'no';
			update_post_meta($post_id, '_export_to_ffve_services', $export_to_ffve_services);
		}
		public function upload_ffve_products() {
			// Définir le chemin vers le dossier temporaire
			$temp_dir = wp_upload_dir()['basedir'] . '/export-ffve-services';
			// Créer le dossier temporaire s'il n'existe pas
			if (!file_exists($temp_dir)) {
				if (_FFVE_SERVICES_DEBUG_)
				error_log("create dir $temp_dir");
				$res = wp_mkdir_p($temp_dir);
				if (!$res){
					print json_encode(['success'=>false,'message'=>'Impossible de créer : ' . $temp_dir]);
					wp_die();
				}
			}
			// Générer un nom de fichier aléatoire
			$random_file_name = 'FFVE-SERVICES-Export-' . uniqid() . '.csv';
			// Définir le chemin complet du fichier temporaire
			$file_path = $temp_dir . '/' . $random_file_name;
			$res = $this->export_ffve_products($file_path);
			$ffve_settings = new FFVE_SETTINGS();
			$ffve_api = new FFVE_API($ffve_settings->getServer(), $ffve_settings->getUser(), $ffve_settings->getPassword() );
			$result=$ffve_api->uploadProducts($file_path);	
			print json_encode($result);
			wp_die();
		}		 
		public function cleanTextExport($txt) {
			$txt = strip_tags($txt, '<ul><li><br><strong>');
			$search=["\n","\r"];
			$txt=str_replace($search, '||', $txt);
			$txt=str_replace(",", '##', $txt);
			return $txt;
		}
		public function export_ffve_products($file=NULL) {
			// Vérifier si l'utilisateur a les permissions nécessaires
			if (!current_user_can('manage_woocommerce')) {
				wp_die(__('Vous n\'avez pas la permission d\'accéder à cette page.', 'ffveservices'));
			}
			// Récupérer tous les produits ayant la case à cocher "Exporter ce produit sur FFVE Services" cochée
			$args = array(
			'post_type' => 'product',
			'posts_per_page' => -1,
			'meta_query' => array(
            array(
			'key' => '_export_to_ffve_services',
			'value' => 'yes',
			'compare' => '='
            )
			)
			);
			$products = new WP_Query($args);
			// Initialiser le tableau des détails des produits
			$productDetails = array();
			
			//Spécifique WPML
			if (function_exists('icl_object_id')) {
			// Récupérer la langue active via WPML
			$current_language = apply_filters('wpml_current_language', null);
			$isWPML=true;
			}else{
			$isWPML=false;
			}
			
			// Parcourir les produits
			if ($products->have_posts()) {
				while ($products->have_posts()) {
					$products->the_post();
					$product_id = get_the_ID();
					$product = wc_get_product($product_id);
					// Vérifier si WPML est actif
					if ($isWPML){
						// Récupérer l'URL du produit en fonction de la langue active
						$product_url = apply_filters('wpml_permalink', get_permalink($product_id), $current_language);
						} else {
						// Si WPML n'est pas actif, utiliser l'URL par défaut
						$product_url = get_permalink($product_id);
					}	
					// Récupérer toutes les catégories du produit
					$categories = wp_get_post_terms($product_id, 'product_cat');
					// Extraire les noms des catégories
					$category_names = wp_list_pluck($categories, 'name');
					// Extraire les URL des catégories
					$category_urls = array_map(function($category) {
						return get_term_link($category);
					}, $categories);
					// Récupérer les informations du produit
					$productDetails[] = array(
					'id_product' => $product->get_id(),
					'name' => $this->cleanTextExport($this->cleanTextExport($product->get_name())),
					'price' => $product->get_price(),
					'image_url' => wp_get_attachment_url($product->get_image_id()),
					'product_url' => $product_url,
					'category_name' => implode('||', $category_names),
					'category_url' => implode('||', $category_urls),
					'short_description' => $this->cleanTextExport( $product->get_short_description()), 
					'long_description' =>  $this->cleanTextExport( $product->get_description()) 
					);
				}
				wp_reset_postdata();
			}
			if (!$file){
				// Sortie sur stdout
				// Définir les en-têtes pour le téléchargement CSV
				header('Content-Type: text/csv');
				header('Content-Disposition: attachment; filename="FFVE-SERVICES-Export-' . date('YmdHis') . '.csv"');
				// Sortie des colonnes CSV
				if (!empty($productDetails)) {
					$columns = array_keys(reset($productDetails));
					echo implode(',', $columns) . "\n";
					// Sortie des détails des produits
					foreach ($productDetails as $productDetail) {
						echo '"' . implode('","', $productDetail) . '"' . "\n";
					}
				}
				exit;
				}else{
				// Sortie sur fichier $file
				// Ouverture du fichier en écriture
				$output = fopen($file, 'w');
				// Vérification de l'ouverture du fichier
				if ($output === false) {
					// Gérer l'erreur d'ouverture du fichier
					return false;
				}
				// Sortie des colonnes CSV
				if (!empty($productDetails)) {
					$columns = array_keys(reset($productDetails));
					fputcsv($output, $columns);
					// Sortie des détails des produits
					foreach ($productDetails as $productDetail) {
						fputcsv($output, $productDetail);
					}
				}
				// Fermeture du fichier
				fclose($output);
				return true;
			}
		}
	}	