<?php
	class FFVE_UPDATE {
		const UPDATE_URL = 'https://api.ffveservices.com/wp-json/dbl-ffve/plugins/';
		
		private $plugin_slug;
		private $current_version; 
		
		public function __construct() {
			$this->plugin_slug = _FFVE_BASENAME;
			$this->current_version = _FFVE_SERVICES_VERSION_;  // Version actuelle du plugin
			add_filter('pre_set_site_transient_update_plugins', array($this, 'check_for_update'));
			add_filter('plugins_api', array($this, 'plugin_info'), 20, 3);
		}
		
		public function check_for_update($transient) {
			if (empty($transient->checked)) {
				return $transient;
			}
			
			// URL pour vérifier les mises à jour
			$remote_url = self::UPDATE_URL . 'woocommerce-ffve-plugin?slug=' . $this->plugin_slug . '&version=' . $this->current_version;
			$response = wp_remote_get($remote_url);
			
			if (is_wp_error($response) || wp_remote_retrieve_response_code($response) != 200) {
				return $transient;
			}
			
			$remote_data = json_decode(wp_remote_retrieve_body($response));
			
			if (version_compare($this->current_version, $remote_data->new_version, '<')) {
				$transient->response[$this->plugin_slug] = (object) array(
                'slug'        => $this->plugin_slug,
                'new_version' => $remote_data->new_version,
                'url'         => self::UPDATE_URL . 'woocommerce-ffve-plugin-info',  // URL pour plus d'infos sur la mise à jour
                'package'     => $remote_data->package,
				);
			}
			
			return $transient;
		}
		
		public function plugin_info($false, $action, $args) {
			if ($action !== 'plugin_information' || $args->slug !== $this->plugin_slug) {
				return false;
			}
			
			// URL pour obtenir les informations du plugin
			$remote_url = self::UPDATE_URL . 'woocommerce-ffve-plugin-info?slug=' . $this->plugin_slug;
			$response = wp_remote_get($remote_url);
			if (is_wp_error($response) || wp_remote_retrieve_response_code($response) != 200) {
				return false;
			}
			$remote_data = json_decode(wp_remote_retrieve_body($response));
			return (object) array(
			'name'          => $remote_data->name,
			'slug'          => $this->plugin_slug,
			'version'       => $remote_data->version,
			'author'        => $remote_data->author,
			'homepage'      => $remote_data->homepage,
			'short_description' => $remote_data->short_description,
			'sections'      => array(
			'description'  => $remote_data->description,
			'installation' => $remote_data->installation,
			'changelog'    => $remote_data->changelog,
			),
			'download_link' => $remote_data->download_link,
			// Ajout des bannières
			'banners'       => array(
			'low'  => $remote_data->banners->low,  // URL de la bannière de basse résolution
			'high' => $remote_data->banners->high, // URL de la bannière de haute résolution
			),
			);
		}
	}
